"""
    BasisTheory Vault API

    No description provided (generated by Openapi Generator https://github.com/openapitools/openapi-generator)  # noqa: E501

    The version of the OpenAPI document: v1
    Generated by: https://openapi-generator.tech
"""


import sys
import unittest

import basistheory
from basistheory.model.pagination import Pagination
from basistheory.model.token import Token
globals()['Pagination'] = Pagination
globals()['Token'] = Token
from basistheory.model.token_paginated_list import TokenPaginatedList


class TestTokenPaginatedList(unittest.TestCase):
    """TokenPaginatedList unit test stubs"""

    def setUp(self):
        pass

    def tearDown(self):
        pass

    def testTokenPaginatedList(self):
        """Test TokenPaginatedList"""
        # FIXME: construct object with mandatory attributes with example values
        # model = TokenPaginatedList()  # noqa: E501
        pass


if __name__ == '__main__':
    unittest.main()
