"""
    Basis Theory API

    ## Getting Started * Sign-in to [Basis Theory](https://basistheory.com) and go to [Applications](https://portal.basistheory.com/applications) * Create a Basis Theory Private Application * All permissions should be selected * Paste the API Key into the `BT-API-KEY` variable  # noqa: E501

    The version of the OpenAPI document: v1
    Generated by: https://openapi-generator.tech
"""


import unittest

import basistheory
from basistheory.api.sessions_api import SessionsApi  # noqa: E501


class TestSessionsApi(unittest.TestCase):
    """SessionsApi unit test stubs"""

    def setUp(self):
        self.api = SessionsApi()  # noqa: E501

    def tearDown(self):
        pass

    def test_authorize(self):
        """Test case for authorize

        """
        pass

    def test_create(self):
        """Test case for create

        """
        pass


if __name__ == '__main__':
    unittest.main()
