"""
    BasisTheory Vault API

    No description provided (generated by Openapi Generator https://github.com/openapitools/openapi-generator)  # noqa: E501

    The version of the OpenAPI document: v1
    Generated by: https://openapi-generator.tech
"""


import unittest

import basistheory
from basistheory.api.tenants_api import TenantsApi  # noqa: E501


class TestTenantsApi(unittest.TestCase):
    """TenantsApi unit test stubs"""

    def setUp(self):
        self.api = TenantsApi()  # noqa: E501

    def tearDown(self):
        pass

    def test_delete(self):
        """Test case for delete

        """
        pass

    def test_get(self):
        """Test case for get

        """
        pass

    def test_get_tenant_operation_report(self):
        """Test case for get_tenant_operation_report

        """
        pass

    def test_get_tenant_usage_report(self):
        """Test case for get_tenant_usage_report

        """
        pass

    def test_update(self):
        """Test case for update

        """
        pass


if __name__ == '__main__':
    unittest.main()
